===========
bruges is a
===========

.. image:: http://agile.geosci.ai/bruges.png

In other words, it's just a load of functions that implement important equations in (mostly seismic) geophysics, from Aki-Richards to Zoeppritz.


Status
+++++++

.. image:: https://img.shields.io/travis/agile-geoscience/bruges.svg
    :target: https://travis-ci.org/agile-geoscience/bruges
    :alt: Travis build status
    
.. image:: https://readthedocs.org/projects/bruges/badge/?version=latest
    :target: https://bruges.readthedocs.io/?badge=latest
    :alt: Documentation Status    
    
.. image:: https://img.shields.io/pypi/status/bruges.svg
    :target: https://pypi.python.org/pypi/bruges/
    :alt: Development status

.. image:: https://img.shields.io/pypi/v/bruges.svg
    :target: https://pypi.python.org/pypi/bruges/
    :alt: Latest version
    
.. image:: https://img.shields.io/pypi/pyversions/bruges.svg
    :target: https://pypi.python.org/pypi/bruges/
    :alt: Python version

.. image:: https://img.shields.io/pypi/l/bruges.svg
    :target: http://www.apache.org/licenses/LICENSE-2.0
    :alt: License

.. line-block::
   The bruges module contains several common geophysics functions 
   used for modelling and post-processing seismic reflection data.


Installation
++++++++++++
Install with

.. code-block:: shell

    pip install bruges

**bruges** requires NumPy and SciPy.


Links
+++++
* `Documentation <https://bruges.readthedocs.org>`_
* `Project page <http://agile-geoscience.github.com/bruges/>`_
* `Issue Tracker <https://github.com/agile-geoscience/bruges/issues/>`_
* `PyPi <http://pypi.python.org/pypi/bruges/>`_
* `Agile Geoscience <http://www.agilegeoscience.com>`_


.. image:: https://www.dropbox.com/s/tzvi22ujq6rozdb/bruges_long_rooves.png?raw=1
